@@ -58,9 +58,14 @@ pub struct RBatisConnExecutor<'a> {
     pub rb: &'a Rbatis,
 }
 
-impl<'a> RBatisConnExecutor<'a> {
-    pub fn as_executor(&'a mut self) -> RbatisExecutor<'a> {
-        self.into()
+impl<'b> RBatisConnExecutor<'b> {
+    pub fn as_executor<'a>(&'a mut self) -> RbatisExecutor<'a, 'b> {
+        RbatisExecutor {
+            rb: None,
+            guard: None,
+            conn: Some(self),
+            tx: None,
+        }
     }
 }
 
@@ -189,8 +194,8 @@ pub struct RBatisTxExecutor<'a> {
     pub rb: &'a Rbatis,
 }
 
-impl<'a> RBatisTxExecutor<'a> {
-    pub fn as_executor(&'a mut self) -> RbatisExecutor<'a> {
+impl<'a, 'b> RBatisTxExecutor<'b> {
+    pub fn as_executor(&'a mut self) -> RbatisExecutor<'a, 'b> {
         self.into()
     }
 }
@@ -233,8 +238,8 @@ pub struct RBatisTxExecutorGuard<'a> {
     pub callback: Box<dyn FnMut(RBatisTxExecutor<'a>) + Send + 'a>,
 }
 
-impl<'a> RBatisTxExecutorGuard<'a> {
-    pub fn as_executor(&'a mut self) -> RbatisExecutor<'a> {
+impl<'a, 'b> RBatisTxExecutorGuard<'b> {
+    pub fn as_executor(&'a mut self) -> RbatisExecutor<'a, 'b> {
         self.into()
     }
 
@@ -352,19 +357,23 @@ impl Executor for Rbatis {
     }
 }
 
+
 /// must be only one have Some(Value)
 /// (&rb).into()
+/// &mut tx.as_executor()
+/// &mut conn.as_executor()
+/// &mut guard.as_executor()
 /// (&mut tx).into()
 /// (&mut conn).into()
 /// (&mut guard).into()
-pub struct RbatisExecutor<'a> {
-    pub rb: Option<&'a Rbatis>,
-    pub conn: Option<&'a mut RBatisConnExecutor<'a>>,
-    pub tx: Option<&'a mut RBatisTxExecutor<'a>>,
-    pub guard: Option<&'a mut RBatisTxExecutorGuard<'a>>,
+pub struct RbatisExecutor<'r, 'inner> {
+    pub rb: Option<&'r Rbatis>,
+    pub conn: Option<&'r mut RBatisConnExecutor<'inner>>,
+    pub tx: Option<&'r mut RBatisTxExecutor<'inner>>,
+    pub guard: Option<&'r mut RBatisTxExecutorGuard<'inner>>,
 }
 
-impl RbatisExecutor<'_> {
+impl RbatisExecutor<'_, '_> {
     pub async fn fetch_page<T>(&mut self, sql: &str, args: Vec<Value>, page_request: &dyn IPageRequest) -> crate::Result<Page<T>>
         where
             T: DeserializeOwned + Serialize + Send + Sync {
@@ -407,7 +416,7 @@ impl RbatisExecutor<'_> {
     }
 }
 
-impl<'a> RbatisRef for RbatisExecutor<'a> {
+impl<'r, 'inner> RbatisRef for RbatisExecutor<'r, 'inner> {
     fn get_rbatis(&self) -> &Rbatis {
         if self.rb.is_some() {
             return self.rb.as_ref().unwrap();
@@ -423,8 +432,8 @@ impl<'a> RbatisRef for RbatisExecutor<'a> {
     }
 }
 
-impl<'a> From<&'a Rbatis> for RbatisExecutor<'a> {
-    fn from(arg: &'a Rbatis) -> Self {
+impl<'r, 'inner> From<&'r Rbatis> for RbatisExecutor<'r, 'inner> {
+    fn from(arg: &'r Rbatis) -> Self {
         Self {
             rb: Some(arg),
             conn: None,
@@ -434,8 +443,8 @@ impl<'a> From<&'a Rbatis> for RbatisExecutor<'a> {
     }
 }
 
-impl<'a> From<&'a mut RBatisConnExecutor<'a>> for RbatisExecutor<'a> {
-    fn from(arg: &'a mut RBatisConnExecutor<'a>) -> Self {
+impl<'r, 'inner> From<&'r mut RBatisConnExecutor<'inner>> for RbatisExecutor<'r, 'inner> {
+    fn from(arg: &'r mut RBatisConnExecutor<'inner>) -> Self {
         Self {
             rb: None,
             conn: Some(arg),
@@ -445,8 +454,8 @@ impl<'a> From<&'a mut RBatisConnExecutor<'a>> for RbatisExecutor<'a> {
     }
 }
 
-impl<'a> From<&'a mut RBatisTxExecutor<'a>> for RbatisExecutor<'a> {
-    fn from(arg: &'a mut RBatisTxExecutor<'a>) -> Self {
+impl<'r, 'inner> From<&'r mut RBatisTxExecutor<'inner>> for RbatisExecutor<'r, 'inner> {
+    fn from(arg: &'r mut RBatisTxExecutor<'inner>) -> Self {
         Self {
             rb: None,
             conn: None,
@@ -456,8 +465,8 @@ impl<'a> From<&'a mut RBatisTxExecutor<'a>> for RbatisExecutor<'a> {
     }
 }
 
-impl<'a> From<&'a mut RBatisTxExecutorGuard<'a>> for RbatisExecutor<'a> {
-    fn from(arg: &'a mut RBatisTxExecutorGuard<'a>) -> Self {
+impl<'r, 'inner> From<&'r mut RBatisTxExecutorGuard<'inner>> for RbatisExecutor<'r, 'inner> {
+    fn from(arg: &'r mut RBatisTxExecutorGuard<'inner>) -> Self {
         Self {
             rb: None,
             conn: None,
